%%%% DAVID MEHRLE
%%%% dfm223@cornell.edu

%% --------------------------------------------------------------
%% A document class for handouts for my students. Based on (and 
%% mostly copied from) the article document class, and using some
%% modified code from Drew Zemke's recitation document class; 
%% inspired by the same. 
%% --------------------------------------------------------------


\def\fileversion{1.1}
\def\filedate{2018/08/21}

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{handout}[\filedate\space Version \fileversion\space by David Mehrle]

\RequirePackage{ifthen}

% provide an option at the document class level
\newif\ifanswers
\answersfalse
\DeclareOption{answers}{\answerstrue}
\DeclareOption{noanswers}{\answersfalse}

\newif\ifname
\nametrue
\DeclareOption{name}{\nametrue}
\DeclareOption{noname}{\namefalse}

%Code from the article document class that this is based on.
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}

%%% Secret vanishing solutions, Batman!
%%% --------------------------------------------------------------
\ifanswers
\newenvironment{solution}{\color{blue}\textsc{Solution}: }{}
\else
\RequirePackage{comment} % this package is key to a "dummy" environment
\newenvironment{solution}{}{}
\excludecomment{solution}
\fi
\ifanswers
\newenvironment{answer}{\color{blue}\textsc{Answer}: }{}
\else
\RequirePackage{comment} % this package is key to a "dummy" environment
\newenvironment{answer}{}{}
\excludecomment{answer}
\fi

\ifanswers
\RequirePackage{comment}
\newenvironment{studentonly}{}{}
\excludecomment{studentonly}
\else
\newenvironment{studentonly}{}{}
\fi

\ifanswers
\newenvironment{hidden}{\color{blue}}{}
\else
\RequirePackage{comment} % this package is key to a "dummy" environment
\newenvironment{hidden}{}{}
\excludecomment{hidden}
\fi

\ifanswers
\newenvironment{answersonly}{\color{blue}}{}
\else
\RequirePackage{comment} % this package is key to a "dummy" environment
\newenvironment{answersonly}{}{}
\excludecomment{answersonly}
\fi


\ifanswers
\newenvironment{highlight}{\color{blue}}{}
\else
\newenvironment{highlight}{}{}
\fi


%%% FILL-IN (THANKS DREW ZEMKE!)
% Put this around (math) items that you would like the 
%  students to fill in during class.
% Fill-in for math text:
\RequirePackage{color}
\RequirePackage{amsmath} %for the `\boxed` macro
\definecolor{light-gray}{gray}{0.8}
\newcounter{fillinCounter}
\newcommand{\fillin}[1]{
	\stepcounter{fillinCounter}
	{\color{light-gray}\boxed{\quad\color{black}
			\ifanswers
				{\color{blue} #1}
			\else
				{\phantom{#1}}
			\fi
		\quad}^{\,(\arabic{fillinCounter})}
	}
}

% Fill-in for regular (prose) text:
\newcommand{\fillint}[1]{$\fillin{\mbox{#1}}$}

%%% --------------------------------------------------------------




%%% Modifies the \maketitle command to include class info
%%% --------------------------------------------------------------
\ifanswers
\ifname
\newcommand{\name}{\textsc{\Large Name: \underline{\color{blue} Solutions}}}
\else
\newcommand{\name}{}
\fi
\else
\ifname
\newcommand{\name}{\textsc{\Large Name: \underline{\phantom{First Name Last Name}}}}
\else
\newcommand{\name}{}
\fi
\fi
\makeatletter
\newcommand\@class\relax
\newcommand{\class}[1]{\def\@class{#1}}
\newcommand\@classsection\relax
\newcommand{\classsection}[1]{\def\@classsection{#1}}
\renewcommand{\maketitle}{
  \let\footnotesize\small
  \let\footnoterule\relax
  \let \footnote \thanks
  {\noindent \textsc{\Large \@title} \hfill {\name} \\
  \@class \hfill \@date} 
  %% Bug: when class is empty, the date is not on the right
  %% Is this really a bug?
  
  \vspace*{1em}
  
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\@class\@empty
  \global\let\@classsection\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\class\relax
  \global\let\classsection\relax
  \global\let\place\relax
  \global\let\and\relax
}
\makeatother
%%% --------------------------------------------------------------


%%% TABLE OF CONTENTS FIXES
\RequirePackage[titles]{tocloft}
%%% ADD DOTS TO TABLE OF CONTENTS
\renewcommand\cftsecleader{\cftdotfill{\cftdotsep}}
%%% UN-BOLD THE TABLE OF CONTENTS
\renewcommand\cftsecfont{\normalfont}
\renewcommand\cftsecpagefont{\normalfont}


% Make the section headings in small caps
\RequirePackage[sc]{titlesec}

